@@ -23,23 +23,22 @@ from hyperspy.component import Component
 
 class VolumePlasmonDrude(Component):
 
-    """Drude volume plasmon energy loss function component
+    r"""Drude volume plasmon energy loss function component, the energy loss 
+    function is defined as:
 
     .. math::
 
-       Energy loss function defined as:
+       f(E) = \frac{E(\Delta E_p)E_p^2}{(E^2-E_p^2)^2+(E\Delta E_p)^2}
 
-       f(E) = \\frac{E(\Delta E_p)E_p^2}{(E^2-E_p^2)^2+(E\Delta E_p)^2}
-
-    +------------+-----------------+
-    | Parameter  |    Attribute    |
-    +------------+-----------------+
-    |    E_p     |  plasmon_energy |
-    +------------+-----------------+
-    | delta_E_p  |      fwhm       |
-    +------------+-----------------+
-    | intensity  |   intensity     |
-    +------------+-----------------+
+    +------------------+-----------------+
+    | Parameter        |    Attribute    |
+    +------------------+-----------------+
+    |:math:`E_p`       |  plasmon_energy |
+    +------------------+-----------------+
+    |:math:`\Delta E_p`|      fwhm       |
+    +------------------+-----------------+
+    | intensity        |   intensity     |
+    +------------------+-----------------+
 
     Notes
     -----
