@@ -18,10 +18,16 @@
 
 import numpy as np
 import matplotlib.pyplot as plt
+import logging
 
 from hyperspy.drawing.widgets import Widget2DBase, ResizersMixin
 
 
+_logger = logging.getLogger(__name__)
+# Track if we have already warned when the widget is out of range
+already_warn_out_of_range = False
+
+
 class SquareWidget(Widget2DBase):
 
     """SquareWidget is a symmetric, Rectangle-patch based widget, which can be
@@ -140,17 +146,66 @@ class RectangleWidget(SquareWidget, ResizersMixin):
         If specifying with keywords, any unspecified dimensions will be kept
         constant (note: width/height will be kept, not right/bottom).
         """
-
+        global already_warn_out_of_range
         x, y, w, h = self._parse_bounds_args(args, kwargs)
 
-        if not (self.axes[0].low_value <= x <= self.axes[0].high_value):
-            raise ValueError()
-        if not (self.axes[1].low_value <= y <= self.axes[1].high_value):
-            raise ValueError()
-        if not (self.axes[0].low_value <= x + w <= self.axes[0].high_value):
-            raise ValueError()
-        if not (self.axes[1].low_value <= y + h <= self.axes[1].high_value):
-            raise ValueError()
+        def warn(obj, parameter, value):
+            global already_warn_out_of_range
+            if not already_warn_out_of_range:
+                _logger.info('{}: {} is out of range. It is therefore set '
+                             'to the value of {}'.format(obj, parameter, value))
+                already_warn_out_of_range = True
+
+        scale = [axis.scale for axis in self.axes]
+        l0, h0 = self.axes[0].low_value, self.axes[0].high_value
+        l1, h1 = self.axes[1].low_value, self.axes[1].high_value
+
+        in_range = 0
+        if x < l0:
+            x = l0
+            warn(self, '`x`', x)
+        elif h0 <= x:
+            x = h0 - scale[0]
+            warn(self, '`x`', x)
+        else:
+            in_range += 1
+        if y < l1:
+            y = l1
+            warn(self, '`y`', y)
+        elif h1 <= y:
+            warn(self, '`y`', y)
+            y = h1 - scale[1]
+        else:
+            in_range += 1
+        if w < scale[0]:
+            w = scale[0]
+            warn(self, '`width` or `right`', w)
+        elif not (l0 + scale[0] <= x + w <= h0 + scale[0]):
+            if self.size[0] != w:  # resize
+                w = h0 + scale[0] - self.position[0]
+                warn(self, '`width` or `right`', w)
+            if self.position[0] != x:  # moved
+                x = h0 + scale[0] - self.size[0]
+                warn(self, '`x`', x)
+        else:
+            in_range += 1
+        if h < scale[1]:
+            h = scale[1]
+            warn(self, '`height` or `bottom`', h)
+        elif not (l1 + scale[1] <= y + h <= h1 + scale[1]):
+            if self.size[1] != h:  # resize
+                h = h1 + scale[1] - self.position[1]
+                warn(self, '`height` or `bottom`', h)
+            if self.position[1] != y:  # moved
+                y = h1 + scale[1] - self.size[1]
+                warn(self, '`y`', y)
+        else:
+            in_range += 1
+
+        # if we are in range again, reset `already_warn_out_of_range` to False
+        if in_range == 4 and already_warn_out_of_range:
+            _logger.info('{} back in range.'.format(self.__class__.__name__))
+            already_warn_out_of_range = False
 
         old_position, old_size = self.position, self.size
         self._pos = np.array([x, y])
@@ -175,9 +230,11 @@ class RectangleWidget(SquareWidget, ResizersMixin):
         if value == self.width:
             return
         ix = self.indices[0] + value
-        if value <= 0 or \
-                not (self.axes[0].low_index <= ix <= self.axes[0].high_index):
-            raise ValueError()
+        il0, ih0 = self.axes[0].low_index, self.axes[0].high_index
+        if value <= 0 or not (il0 < ix <= ih0):
+            raise ValueError('`width` value is not in range. The '
+                             '`width` is {} and should be in range '
+                             '{}-{}.'.format(ix, il0 + 1, ih0))
         self._set_a_size(0, value)
 
     @property
@@ -189,9 +246,11 @@ class RectangleWidget(SquareWidget, ResizersMixin):
         if value == self.height:
             return
         iy = self.indices[1] + value
-        if value <= 0 or \
-                not (self.axes[1].low_index <= iy <= self.axes[1].high_index):
-            raise ValueError()
+        il1, ih1 = self.axes[1].low_index, self.axes[1].high_index
+        if value <= 0 or not (il1 < iy <= ih1):
+            raise ValueError('`height` value is not in range. The '
+                             '`height` is {} and should be in range '
+                             '{}-{}.'.format(iy, il1 + 1, ih1))
         self._set_a_size(1, value)
 
     # --------- Internal functions ---------
