@@ -21,10 +21,10 @@ import logging
 
 from hyperspy.io_plugins import (msa, digital_micrograph, fei, mrc, ripple,
                                  tiff, semper_unf, blockfile, dens, emd,
-                                 protochips, edax)
+                                 protochips, edax, bcf)
 
 io_plugins = [msa, digital_micrograph, fei, mrc, ripple, tiff, semper_unf,
-              blockfile, dens, emd, protochips, edax]
+              blockfile, dens, emd, protochips, edax, bcf]
 
 _logger = logging.getLogger(__name__)
 
@@ -51,14 +51,6 @@ try:
 except ImportError:
     _logger.info('The Signal2D (PIL) IO features are not available')
 
-try:
-    from hyperspy.io_plugins import bcf
-    io_plugins.append(bcf)
-except ImportError:
-    _logger.warning('The Bruker composite file reader can not be loaded '
-                    'because the lxml library is not installed. To enable it '
-                    'install the Python lxml package.')
-
 default_write_ext = set()
 for plugin in io_plugins:
     if plugin.writes:
