@@ -475,7 +475,7 @@ def dict2hdfgroup(dictionary, group, **kwds):
         else:
             try:
                 group.attrs[key] = value
-            except:
+            except BaseException:
                 _logger.exception(
                     "The hdf5 writer could not write the following "
                     "information in the file: %s : %s", key, value)
@@ -558,8 +558,10 @@ def overwrite_dataset(group, data, key, signal_axes=None, **kwds):
     else:
         if isinstance(data, da.Array):
             da.store(data.rechunk(dset.chunks), dset)
+        elif data.flags.c_contiguous:
+            dset.write_direct(data)
         else:
-            da.store(da.from_array(data, chunks=dset.chunks), dset)
+            dset[:] = data
 
 
 def hdfgroup2dict(group, dictionary=None, lazy=False):
@@ -727,7 +729,7 @@ def file_writer(filename,
             smd.record_by = ""
         try:
             write_signal(signal, expg, **kwds)
-        except:
+        except BaseException:
             raise
         finally:
             del smd.record_by
