@@ -434,8 +434,6 @@ class BaseInteractiveROI(BaseROI):
 
         # Set DataAxes
         widget.axes = axes
-        with widget.events.changed.suppress_callback(self._on_widget_change):
-            self._apply_roi2widget(widget)
         if widget.ax is None:
             if signal._plot is None:
                 raise Exception(
@@ -445,6 +443,8 @@ class BaseInteractiveROI(BaseROI):
 
             ax = _get_mpl_ax(signal._plot, axes)
             widget.set_mpl_ax(ax)
+        with widget.events.changed.suppress_callback(self._on_widget_change):
+            self._apply_roi2widget(widget)
 
         # Connect widget changes to on_widget_change
         widget.events.changed.connect(self._on_widget_change,
@@ -944,7 +944,7 @@ class Line2DROI(BaseInteractiveROI):
     x1, y1, x2, y2, linewidth = (t.CFloat(t.Undefined),) * 5
     _ndim = 2
 
-    def __init__(self, x1, y1, x2, y2, linewidth):
+    def __init__(self, x1, y1, x2, y2, linewidth=0):
         super(Line2DROI, self).__init__()
         self.x1, self.y1, self.x2, self.y2 = x1, y1, x2, y2
         self.linewidth = linewidth
@@ -986,6 +986,7 @@ class Line2DROI(BaseInteractiveROI):
     @staticmethod
     def _line_profile_coordinates(src, dst, linewidth=1):
         """Return the coordinates of the profile of an image along a scan line.
+
         Parameters
         ----------
         src : 2-tuple of numeric scalar (float or int)
@@ -1004,6 +1005,7 @@ class Line2DROI(BaseInteractiveROI):
         This is a utility method meant to be used internally by skimage
         functions. The destination point is included in the profile, in
         contrast to standard numpy indexing.
+
         """
         src_row, src_col = src = np.asarray(src, dtype=float)
         dst_row, dst_col = dst = np.asarray(dst, dtype=float)
@@ -1015,7 +1017,6 @@ class Line2DROI(BaseInteractiveROI):
         # (in contrast to standard numpy indexing)
         line_col = np.linspace(src_col, dst_col, length)
         line_row = np.linspace(src_row, dst_row, length)
-        linewidth = int(linewidth)
         data = np.zeros((2, length, linewidth))
         data[0, :, :] = np.tile(line_col, [linewidth, 1]).T
         data[1, :, :] = np.tile(line_row, [linewidth, 1]).T
@@ -1043,6 +1044,7 @@ class Line2DROI(BaseInteractiveROI):
     def profile_line(img, src, dst, axes, linewidth=1,
                      order=1, mode='constant', cval=0.0):
         """Return the intensity profile of an image measured along a scan line.
+
         Parameters
         ----------
         img : numeric array, shape (M, N[, C])
@@ -1085,15 +1087,22 @@ class Line2DROI(BaseInteractiveROI):
         -----
         The destination point is included in the profile, in contrast to
         standard numpy indexing.
-        """
 
+        """
         import scipy.ndimage as nd
+        # Convert points coordinates from axes units to pixels
         p0 = ((src[0] - axes[0].offset) / axes[0].scale,
               (src[1] - axes[1].offset) / axes[1].scale)
         p1 = ((dst[0] - axes[0].offset) / axes[0].scale,
               (dst[1] - axes[1].offset) / axes[1].scale)
+        if linewidth < 0:
+            raise ValueError("linewidth must be positive number")
+        linewidth_px = linewidth / np.min([ax.scale for ax in axes])
+        linewidth_px = int(round(linewidth_px))
+        # Minimum size 1 pixel
+        linewidth_px = linewidth_px if linewidth_px >= 1 else 1
         perp_lines = Line2DROI._line_profile_coordinates(p0, p1,
-                                                         linewidth=linewidth)
+                                                         linewidth=linewidth_px)
         if img.ndim > 2:
             idx = [ax.index_in_array for ax in axes]
             if idx[0] < idx[1]:
@@ -1151,12 +1160,11 @@ class Line2DROI(BaseInteractiveROI):
             axes = self.signal_map[signal][1]
         else:
             axes = self._parse_axes(axes, signal.axes_manager)
-        linewidth = self.linewidth / np.min([ax.scale for ax in axes])
         profile = Line2DROI.profile_line(signal.data,
                                          (self.x1, self.y1),
                                          (self.x2, self.y2),
                                          axes=axes,
-                                         linewidth=linewidth,
+                                         linewidth=self.linewidth,
                                          order=order)
         length = np.linalg.norm(np.diff(
             np.array(((self.x1, self.y1), (self.x2, self.y2))), axis=0),
