@@ -20,8 +20,8 @@
 import time
 import logging
 from multiprocessing import Manager
-from ipyparallel import Reference as ipp_Reference
 import numpy as np
+from dask.array import Array as dar
 
 from hyperspy.utils.parallel_pool import ParallelPool
 from hyperspy.samfire_utils.samfire_worker import create_worker
@@ -29,6 +29,26 @@ from hyperspy.samfire_utils.samfire_worker import create_worker
 _logger = logging.getLogger(__name__)
 
 
+def _walk_compute(athing):
+    if isinstance(athing, dict):
+        this = {}
+        for key, val in athing.items():
+            if isinstance(key, dar):
+                raise ValueError('Dask arrays should not be used as keys')
+            value = _walk_compute(val)
+            this[key] = value
+        return this
+    elif isinstance(athing, list):
+        return [_walk_compute(val) for val in athing]
+    elif isinstance(athing, tuple):
+        return tuple(_walk_compute(val) for val in athing)
+    elif isinstance(athing, dar):
+        _logger.debug('found a dask array!')
+        return athing.compute()
+    else:
+        return athing
+
+
 class SamfirePool(ParallelPool):
     """ Creates and manages a pool of SAMFire workers. For based on
     ParallelPool - either creates processes using multiprocessing, or connects
@@ -135,9 +155,12 @@ class SamfirePool(ParallelPool):
         m_dict = model.signal._to_dictionary(False)
         m_dict['models'] = model.signal.models._models.as_dictionary()
 
+        m_dict = _walk_compute(m_dict)
+
         optional_names = {mall[c].name for c in samfire.optional_components}
 
         if self.is_ipyparallel:
+            from ipyparallel import Reference as ipp_Reference
             _logger.debug('preparing ipyparallel workers')
             direct_view = self.pool.client[:self.num_workers]
             direct_view.block = True
@@ -172,7 +195,7 @@ class SamfirePool(ParallelPool):
 
     def update_parameters(self):
         """Updates various worker parameters.
-        
+
         Currently updates:
             - Optional components (that can be switched off by the worker)
             - Parameter boundaries
