@@ -17,15 +17,18 @@
 # along with  HyperSpy.  If not, see <http://www.gnu.org/licenses/>.
 
 
+import warnings
 import os
-import nose.tools as nt
-import hyperspy.api as hs
-import numpy as np
 import gc
+import tempfile
+
+import numpy as np
+from numpy.testing import assert_allclose
+import pytest
+
 from hyperspy.io_plugins.blockfile import get_default_header
 from hyperspy.misc.array_tools import sarray2dict
-import warnings
-
+import hyperspy.api as hs
 from hyperspy.misc.test_utils import assert_deep_almost_equal
 from hyperspy.misc.date_time_tools import serial_date_to_ISO_format
 
@@ -36,19 +39,18 @@ except NameError:
     WindowsError = None
 
 
-def _remove_file(filename):
-    try:
-        if os.path.exists(filename):
-            os.remove(filename)
-    except WindowsError:
-        pass    # If we don't do this, we might mask real exceptions
+DIRPATH = os.path.dirname(__file__)
+FILE1 = os.path.join(DIRPATH, 'blockfile_data', 'test1.blo')
+FILE2 = os.path.join(DIRPATH, 'blockfile_data', 'test2.blo')
 
 
-dirpath = os.path.dirname(__file__)
-
-file1 = os.path.join(dirpath, 'blockfile_data', 'test1.blo')
-file2 = os.path.join(dirpath, 'blockfile_data', 'test2.blo')
-save_path = os.path.join(dirpath, 'blockfile_data', 'save_temp.blo')
+@pytest.fixture()
+def save_path():
+    with tempfile.TemporaryDirectory() as tmp:
+        filepath = os.path.join(tmp, 'blockfile_data', 'save_temp.blo')
+        yield filepath
+        # Force files release (required in Windows)
+        gc.collect()
 
 ref_data2 = np.array(
     [[[[20, 23, 25, 25, 27],
@@ -118,223 +120,184 @@ axes2 = {
 
 
 def test_load1():
-    s = hs.load(file1)
-    nt.assert_equal(s.data.shape, (3, 2, 144, 144))
-    nt.assert_equal(s.axes_manager.as_dictionary(), axes1)
+    s = hs.load(FILE1)
+    assert s.data.shape == (3, 2, 144, 144)
+    assert s.axes_manager.as_dictionary() == axes1
 
 
 def test_load2():
-    s = hs.load(file2)
-    nt.assert_equal(s.data.shape, (2, 3, 5, 5))
+    s = hs.load(FILE2)
+    assert s.data.shape == (2, 3, 5, 5)
     np.testing.assert_equal(s.axes_manager.as_dictionary(), axes2)
     np.testing.assert_allclose(s.data, ref_data2)
 
 
-def test_save_load_cycle():
+def test_save_load_cycle(save_path):
     sig_reload = None
-    signal = hs.load(file2)
+    signal = hs.load(FILE2)
     serial = signal.original_metadata['blockfile_header']['Acquisition_time']
     date, time, timezone = serial_date_to_ISO_format(serial)
-    nt.assert_equal(signal.metadata.General.original_filename, 'test2.blo')
-    nt.assert_equal(signal.metadata.General.date, date)
-    nt.assert_equal(signal.metadata.General.time, time)
-    nt.assert_equal(signal.metadata.General.time_zone, timezone)
-    nt.assert_equal(
-        signal.metadata.General.notes,
+    assert signal.metadata.General.original_filename == 'test2.blo'
+    assert signal.metadata.General.date == date
+    assert signal.metadata.General.time == time
+    assert signal.metadata.General.time_zone == timezone
+    assert (
+        signal.metadata.General.notes ==
         "Precession angle : \r\nPrecession Frequency : \r\nCamera gamma : on")
     signal.save(save_path, overwrite=True)
     sig_reload = hs.load(save_path)
     np.testing.assert_equal(signal.data, sig_reload.data)
-    nt.assert_equal(signal.axes_manager.as_dictionary(),
-                    sig_reload.axes_manager.as_dictionary())
-    nt.assert_equal(signal.original_metadata.as_dictionary(),
-                    sig_reload.original_metadata.as_dictionary())
+    assert (signal.axes_manager.as_dictionary() ==
+            sig_reload.axes_manager.as_dictionary())
+    assert (signal.original_metadata.as_dictionary() ==
+            sig_reload.original_metadata.as_dictionary())
     # change original_filename to make the metadata of both signals equals
     sig_reload.metadata.General.original_filename = signal.metadata.General.original_filename
     assert_deep_almost_equal(signal.metadata.as_dictionary(),
                              sig_reload.metadata.as_dictionary())
-    nt.assert_equal(
-        signal.metadata.General.date,
+    assert (
+        signal.metadata.General.date ==
         sig_reload.metadata.General.date)
-    nt.assert_equal(
-        signal.metadata.General.time,
+    assert (
+        signal.metadata.General.time ==
         sig_reload.metadata.General.time)
-    nt.assert_is_instance(signal, hs.signals.Signal2D)
+    assert isinstance(signal, hs.signals.Signal2D)
     # Delete reference to close memmap file!
     del sig_reload
-    gc.collect()
-    _remove_file(save_path)
 
 
-def test_different_x_y_scale_units():
+def test_different_x_y_scale_units(save_path):
     # perform load and save cycle with changing the scale on y
-    signal = hs.load(file2)
+    signal = hs.load(FILE2)
     signal.axes_manager[0].scale = 50.0
-    try:
-        signal.save(save_path, overwrite=True)
-        sig_reload = hs.load(save_path)
-        nt.assert_almost_equal(sig_reload.axes_manager[0].scale, 50.0,
-                               places=2)
-        nt.assert_almost_equal(sig_reload.axes_manager[1].scale, 64.0,
-                               places=2)
-        nt.assert_almost_equal(sig_reload.axes_manager[2].scale, 0.0160616,
-                               places=5)
-    finally:
-        # Delete reference to close memmap file!
-        del sig_reload
-        gc.collect()
-        _remove_file(save_path)
+    signal.save(save_path, overwrite=True)
+    sig_reload = hs.load(save_path)
+    assert_allclose(sig_reload.axes_manager[0].scale, 50.0,
+                    atol=1E-2)
+    assert_allclose(sig_reload.axes_manager[1].scale, 64.0,
+                    atol=1E-2)
+    assert_allclose(sig_reload.axes_manager[2].scale, 0.0160616,
+                    atol=1E-5)
 
 
 def test_default_header():
     # Simply check that no exceptions are raised
     header = get_default_header()
-    nt.assert_is_not_none(header)
+    assert header is not None
 
 
-def test_non_square():
+def test_non_square(save_path):
     signal = hs.signals.Signal2D((255 * np.random.rand(10, 3, 5, 6)
                                   ).astype(np.uint8))
-    try:
-        with nt.assert_raises(ValueError):
-            signal.save(save_path, overwrite=True)
-    finally:
-        _remove_file(save_path)
+    with pytest.raises(ValueError):
+        signal.save(save_path, overwrite=True)
 
 
-def test_load_memmap():
-    s = hs.load(file2, load_to_memory=False)
-    nt.assert_is_instance(s.data, np.memmap)
+def test_load_lazy():
+    from dask.array import Array
+    s = hs.load(FILE2, lazy=True)
+    assert isinstance(s.data, Array)
 
 
 def test_load_to_memory():
-    s = hs.load(file2, load_to_memory=True)
-    nt.assert_is_instance(s.data, np.ndarray)
-    nt.assert_true(not isinstance(s.data, np.memmap))
+    s = hs.load(FILE2, lazy=False)
+    assert isinstance(s.data, np.ndarray)
+    assert not isinstance(s.data, np.memmap)
 
 
 def test_load_readonly():
-    s = hs.load(file2, load_to_memory=False, mmap_mode='r')
-    with nt.assert_raises(ValueError):
+    s = hs.load(FILE2, lazy=True)
+    k = next(filter(lambda x: isinstance(x, str) and
+                    x.startswith("array-original"),
+                    s.data.dask.keys()))
+    mm = s.data.dask[k]
+    assert isinstance(mm, np.memmap)
+    assert not mm.flags["WRITEABLE"]
+    with pytest.raises(NotImplementedError):
         s.data[:] = 23
 
 
 def test_load_inplace():
-    sig_reload = None
-    signal = hs.signals.Signal2D((255 * np.random.rand(2, 3, 2, 2)
-                                  ).astype(np.uint8))
-    try:
-        signal.save(save_path, overwrite=True)
-        del signal
-        sig_reload = hs.load(save_path, load_to_memory=False, mmap_mode='r+')
-        sig_reload.data[:] = 23
-        # Flush and close memmap:
-        del sig_reload
-        gc.collect()
-        # Check if values were written to disk
-        sig_reload = hs.load(save_path, load_to_memory=False, mmap_mode='r')
-        nt.assert_true(np.all(sig_reload.data == 23))
-    finally:
-        # Delete reference to close memmap file!
-        del sig_reload
-        gc.collect()
-        _remove_file(save_path)
+    with pytest.raises(ValueError):
+        hs.load(FILE2, lazy=True, mmap_mode='r+')
 
 
-def test_write_fresh():
+def test_write_fresh(save_path):
     signal = hs.signals.Signal2D((255 * np.random.rand(10, 3, 5, 5)
                                   ).astype(np.uint8))
-    try:
-        signal.save(save_path, overwrite=True)
-        sig_reload = hs.load(save_path)
-        np.testing.assert_equal(signal.data, sig_reload.data)
-        header = sarray2dict(get_default_header())
-        header.update({
-            'NX': 3, 'NY': 10,
-            'DP_SZ': 5,
-            'SX': 1, 'SY': 1,
-            'SDP': 100,
-            'Data_offset_2': 10 * 3 + header['Data_offset_1'],
-            'Note': '',
-        })
-        header['Data_offset_2'] += header['Data_offset_2'] % 16
-        nt.assert_equal(
-            sig_reload.original_metadata.blockfile_header.as_dictionary(),
-            header)
-    finally:
-        _remove_file(save_path)
+    signal.save(save_path, overwrite=True)
+    sig_reload = hs.load(save_path)
+    np.testing.assert_equal(signal.data, sig_reload.data)
+    header = sarray2dict(get_default_header())
+    header.update({
+        'NX': 3, 'NY': 10,
+        'DP_SZ': 5,
+        'SX': 1, 'SY': 1,
+        'SDP': 100,
+        'Data_offset_2': 10 * 3 + header['Data_offset_1'],
+        'Note': '',
+    })
+    header['Data_offset_2'] += header['Data_offset_2'] % 16
+    assert (
+        sig_reload.original_metadata.blockfile_header.as_dictionary() ==
+        header)
 
 
-def test_write_data_line():
+def test_write_data_line(save_path):
     signal = hs.signals.Signal2D((255 * np.random.rand(3, 5, 5)
                                   ).astype(np.uint8))
-    try:
-        signal.save(save_path, overwrite=True)
-        sig_reload = hs.load(save_path)
-        np.testing.assert_equal(signal.data, sig_reload.data)
-    finally:
-        _remove_file(save_path)
+    signal.save(save_path, overwrite=True)
+    sig_reload = hs.load(save_path)
+    np.testing.assert_equal(signal.data, sig_reload.data)
 
 
-def test_write_data_single():
+def test_write_data_single(save_path):
     signal = hs.signals.Signal2D((255 * np.random.rand(5, 5)
                                   ).astype(np.uint8))
-    try:
-        signal.save(save_path, overwrite=True)
-        sig_reload = hs.load(save_path)
-        np.testing.assert_equal(signal.data, sig_reload.data)
-    finally:
-        _remove_file(save_path)
+    signal.save(save_path, overwrite=True)
+    sig_reload = hs.load(save_path)
+    np.testing.assert_equal(signal.data, sig_reload.data)
 
 
-def test_write_data_am_mismatch():
+def test_write_data_am_mismatch(save_path):
     signal = hs.signals.Signal2D((255 * np.random.rand(10, 3, 5, 5)
                                   ).astype(np.uint8))
     signal.axes_manager.navigation_axes[1].size = 4
-    try:
-        with nt.assert_raises(ValueError):
-            signal.save(save_path, overwrite=True)
-    finally:
-        _remove_file(save_path)
+    with pytest.raises(ValueError):
+        signal.save(save_path, overwrite=True)
 
 
-def test_write_cutoff():
+def test_write_cutoff(save_path):
     signal = hs.signals.Signal2D((255 * np.random.rand(10, 3, 5, 5)
                                   ).astype(np.uint8))
     signal.axes_manager.navigation_axes[0].size = 20
     # Test that it raises a warning
-    try:
-        signal.save(save_path, overwrite=True)
-        with warnings.catch_warnings(record=True) as w:
-            warnings.simplefilter("always")
-            sig_reload = hs.load(save_path)
-            # There can be other warnings so >=
-            assert len(w) >= 1
-            warning_blockfile = ["Blockfile header" in str(warning.message)
-                                 for warning in w]
-            assert True in warning_blockfile
-            assert issubclass(w[warning_blockfile.index(True)].category,
-                              UserWarning)
-        cut_data = signal.data.flatten()
-        pw = [(0, 17 * 10 * 5 * 5)]
-        cut_data = np.pad(cut_data, pw, mode='constant')
-        cut_data = cut_data.reshape((10, 20, 5, 5))
-        np.testing.assert_equal(cut_data, sig_reload.data)
-    finally:
-        _remove_file(save_path)
+    signal.save(save_path, overwrite=True)
+    with warnings.catch_warnings(record=True) as w:
+        warnings.simplefilter("always")
+        sig_reload = hs.load(save_path)
+        # There can be other warnings so >=
+        assert len(w) >= 1
+        warning_blockfile = ["Blockfile header" in str(warning.message)
+                             for warning in w]
+        assert True in warning_blockfile
+        assert issubclass(w[warning_blockfile.index(True)].category,
+                          UserWarning)
+    cut_data = signal.data.flatten()
+    pw = [(0, 17 * 10 * 5 * 5)]
+    cut_data = np.pad(cut_data, pw, mode='constant')
+    cut_data = cut_data.reshape((10, 20, 5, 5))
+    np.testing.assert_equal(cut_data, sig_reload.data)
 
 
-def test_crop_notes():
+def test_crop_notes(save_path):
     note_len = 0x1000 - 0xF0
     note = 'test123' * 1000     # > note_len
     signal = hs.signals.Signal2D((255 * np.random.rand(2, 3, 2, 2)
                                   ).astype(np.uint8))
     signal.original_metadata.add_node('blockfile_header.Note')
     signal.original_metadata.blockfile_header.Note = note
-    try:
-        signal.save(save_path, overwrite=True)
-        sig_reload = hs.load(save_path)
-        nt.assert_equal(sig_reload.original_metadata.blockfile_header.Note,
-                        note[:note_len])
-    finally:
-        _remove_file(save_path)
+    signal.save(save_path, overwrite=True)
+    sig_reload = hs.load(save_path)
+    assert (sig_reload.original_metadata.blockfile_header.Note ==
+            note[:note_len])
